@@ -1,14 +1,16 @@
 import os
+import random
 import sys
 import tempfile
 from contextlib import contextmanager
 
 import pytest
+
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.user
 from tests.support.case import ModuleCase
-from tests.support.helpers import dedent
+from tests.support.helpers import SKIP_INITIAL_PHOTONOS_FAILURES, dedent
 from tests.support.runtests import RUNTIME_VARS
 
 AVAILABLE_PYTHON_EXECUTABLE = salt.utils.path.which_bin(
@@ -41,6 +43,7 @@ class CMDModuleTest(ModuleCase):
                 self.run_function("user.delete", [name], remove=True)
 
     @pytest.mark.slow_test
+    @pytest.mark.skip_on_windows
     def test_run(self):
         """
         cmd.run
@@ -53,7 +56,7 @@ class CMDModuleTest(ModuleCase):
         self.assertTrue(self.run_function("cmd.run", ["echo $SHELL"]))
         self.assertEqual(
             self.run_function(
-                "cmd.run", ["echo $SHELL", "shell={}".format(shell)], python_shell=True
+                "cmd.run", ["echo $SHELL", f"shell={shell}"], python_shell=True
             ).rstrip(),
             shell,
         )
@@ -105,7 +108,7 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(
             self.run_function(
                 "cmd.run_stderr",
-                ['echo "cheese" 1>&2', "shell={}".format(shell)],
+                ['echo "cheese" 1>&2', f"shell={shell}"],
                 python_shell=True,
             ).rstrip(),
             "cheese" if not salt.utils.platform.is_windows() else '"cheese"',
@@ -123,7 +126,7 @@ class CMDModuleTest(ModuleCase):
 
         ret = self.run_function(
             "cmd.run_all",
-            ['echo "cheese" 1>&2', "shell={}".format(shell)],
+            ['echo "cheese" 1>&2', f"shell={shell}"],
             python_shell=True,
         )
         self.assertTrue("pid" in ret)
@@ -174,6 +177,31 @@ class CMDModuleTest(ModuleCase):
 
         self.assertEqual(ret, 0)
 
+    @pytest.mark.slow_test
+    def test_run_all_with_success_stderr(self):
+        """
+        cmd.run with success_retcodes
+        """
+        random_file = "{}{}{}".format(
+            RUNTIME_VARS.TMP_ROOT_DIR, os.path.sep, random.random()
+        )
+
+        if salt.utils.platform.is_windows():
+            func = "type"
+            expected_stderr = "cannot find the file specified"
+        else:
+            func = "cat"
+            expected_stderr = "No such file or directory"
+        ret = self.run_function(
+            "cmd.run_all",
+            [f"{func} {random_file}"],
+            success_stderr=[expected_stderr],
+            python_shell=True,
+        )
+
+        self.assertTrue("retcode" in ret)
+        self.assertEqual(ret.get("retcode"), 0)
+
     @pytest.mark.slow_test
     def test_blacklist_glob(self):
         """
@@ -191,7 +219,7 @@ class CMDModuleTest(ModuleCase):
         """
         args = "saltines crackers biscuits=yes"
         script = "salt://script.py"
-        ret = self.run_function("cmd.script", [script, args])
+        ret = self.run_function("cmd.script", [script, args], saltenv="base")
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
@@ -201,7 +229,7 @@ class CMDModuleTest(ModuleCase):
         """
         args = "saltines crackers biscuits=yes"
         script = "salt://script.py?saltenv=base"
-        ret = self.run_function("cmd.script", [script, args])
+        ret = self.run_function("cmd.script", [script, args], saltenv="base")
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
@@ -210,7 +238,7 @@ class CMDModuleTest(ModuleCase):
         cmd.script_retcode
         """
         script = "salt://script.py"
-        ret = self.run_function("cmd.script_retcode", [script])
+        ret = self.run_function("cmd.script_retcode", [script], saltenv="base")
         self.assertEqual(ret, 0)
 
     @pytest.mark.slow_test
@@ -221,7 +249,9 @@ class CMDModuleTest(ModuleCase):
         tmp_cwd = tempfile.mkdtemp(dir=RUNTIME_VARS.TMP)
         args = "saltines crackers biscuits=yes"
         script = "salt://script.py"
-        ret = self.run_function("cmd.script", [script, args], cwd=tmp_cwd)
+        ret = self.run_function(
+            "cmd.script", [script, args], cwd=tmp_cwd, saltenv="base"
+        )
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
@@ -236,7 +266,9 @@ class CMDModuleTest(ModuleCase):
 
         args = "saltines crackers biscuits=yes"
         script = "salt://script.py"
-        ret = self.run_function("cmd.script", [script, args], cwd=tmp_cwd)
+        ret = self.run_function(
+            "cmd.script", [script, args], cwd=tmp_cwd, saltenv="base"
+        )
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.destructive_test
@@ -362,7 +394,7 @@ class CMDModuleTest(ModuleCase):
         result = self.run_function(
             "cmd.run_all", [cmd], runas=RUNTIME_VARS.RUNNING_TESTS_USER
         )
-        errmsg = "The command returned: {}".format(result)
+        errmsg = f"The command returned: {result}"
         self.assertEqual(result["retcode"], 0, errmsg)
         self.assertEqual(result["stdout"], expected_result, errmsg)
 
@@ -460,7 +492,8 @@ class CMDModuleTest(ModuleCase):
         self.assertNotIn("You have failed the test", cmd_result["stderr"])
         self.assertNotEqual(0, cmd_result["retcode"])
 
-    @pytest.mark.skip_on_windows(reason="Minion is Windows")
+    @SKIP_INITIAL_PHOTONOS_FAILURES
+    @pytest.mark.skip_on_windows
     @pytest.mark.skip_if_not_root
     @pytest.mark.destructive_test
     @pytest.mark.slow_test
@@ -472,9 +505,9 @@ class CMDModuleTest(ModuleCase):
             out = self.run_function(
                 "cmd.run", ["env"], runas=self.runas_usr
             ).splitlines()
-        self.assertIn("USER={}".format(self.runas_usr), out)
+        self.assertIn(f"USER={self.runas_usr}", out)
 
-    @pytest.mark.skip_if_binaries_missing("sleep", message="sleep cmd not installed")
+    @pytest.mark.skip_if_binaries_missing("sleep", reason="sleep cmd not installed")
     def test_timeout(self):
         """
         cmd.run trigger timeout
@@ -484,7 +517,7 @@ class CMDModuleTest(ModuleCase):
         )
         self.assertTrue("Timed out" in out)
 
-    @pytest.mark.skip_if_binaries_missing("sleep", message="sleep cmd not installed")
+    @pytest.mark.skip_if_binaries_missing("sleep", reason="sleep cmd not installed")
     def test_timeout_success(self):
         """
         cmd.run sufficient timeout to succeed
@@ -543,7 +576,14 @@ class CMDModuleTest(ModuleCase):
         if user.startswith("sudo_"):
             user = user.replace("sudo_", "")
         cmd = self.run_function("cmd.run", ["whoami"])
-        self.assertEqual(user.lower(), cmd.lower())
+        try:
+            self.assertEqual(user.lower(), cmd.lower())
+        except AssertionError as exc:
+            if not salt.utils.platform.is_windows():
+                raise exc from None
+            if "\\" in user:
+                user = user.split("\\")[-1]
+            self.assertEqual(user.lower(), cmd.lower())
 
     @pytest.mark.skip_unless_on_windows(reason="Minion is not Windows")
     @pytest.mark.slow_test
@@ -564,11 +604,14 @@ class CMDModuleTest(ModuleCase):
         Ensure that powershell processes inline script in args
         """
         val = "i like cheese"
-        args = '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force) -ErrorAction Stop'.format(
-            val
+        args = (
+            '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force)'
+            " -ErrorAction Stop".format(val)
         )
         script = "salt://issue-56195/test.ps1"
-        ret = self.run_function("cmd.script", [script], args=args, shell="powershell")
+        ret = self.run_function(
+            "cmd.script", [script], args=args, shell="powershell", saltenv="base"
+        )
         self.assertEqual(ret["stdout"], val)
 
     @pytest.mark.slow_test
@@ -580,9 +623,12 @@ class CMDModuleTest(ModuleCase):
         core
         """
         val = "i like cheese"
-        args = '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force) -ErrorAction Stop'.format(
-            val
+        args = (
+            '-SecureString (ConvertTo-SecureString -String "{}" -AsPlainText -Force)'
+            " -ErrorAction Stop".format(val)
         )
         script = "salt://issue-56195/test.ps1"
-        ret = self.run_function("cmd.script", [script], args=args, shell="pwsh")
+        ret = self.run_function(
+            "cmd.script", [script], args=args, shell="pwsh", saltenv="base"
+        )
         self.assertEqual(ret["stdout"], val)
