@@ -11,6 +11,17 @@ from saltfactories.utils.tempfiles import temp_file
 from tests.support.case import SSHCase
 from tests.support.runtests import RUNTIME_VARS
 
+pytestmark = [
+    pytest.mark.skipif(
+        "grains['osfinger'] == 'Fedora Linux-39'",
+        reason="Fedora 39 ships with Python 3.12. Test can't run with system Python on 3.12",
+        # Actually, the problem is that the tornado we ship is not prepared for Python 3.12,
+        # and it imports `ssl` and checks if the `match_hostname` function is defined, which
+        # has been deprecated since Python 3.7, so, the logic goes into trying to import
+        # backports.ssl-match-hostname which is not installed on the system.
+    )
+]
+
 SSH_SLS = "ssh_state_tests"
 SSH_SLS_FILE = "/tmp/salt_test_file"
 
@@ -36,7 +47,7 @@ class SSHStateTest(SSHCase):
     def _check_request(self, empty=False):
         check = self.run_function("state.check_request", wipe=False)
         if empty:
-            self.assertFalse(bool(check), "bool({}) is not False".format(check))
+            self.assertFalse(bool(check), f"bool({check}) is not False")
         else:
             self._check_dict_ret(
                 ret=check["default"]["test_run"]["local"]["return"],
