@@ -2,6 +2,7 @@
     tests.pytests.conftest
     ~~~~~~~~~~~~~~~~~~~~~~
 """
+
 import functools
 import inspect
 import logging
@@ -53,7 +54,7 @@ def salt_eauth_account_factory():
 
 @pytest.fixture(scope="session")
 def salt_auto_account_factory():
-    return TestAccount(username="saltdev_auto", password="saltdev")
+    return TestAccount(username="saltdev-auto")
 
 
 @pytest.fixture(scope="session")
@@ -164,7 +165,7 @@ def salt_master_factory(
         "redundant_minions": "N@min or N@mins",
         "nodegroup_loop_a": "N@nodegroup_loop_b",
         "nodegroup_loop_b": "N@nodegroup_loop_a",
-        "missing_minion": "L@{},ghostminion".format(salt_minion_id),
+        "missing_minion": f"L@{salt_minion_id},ghostminion",
         "list_group": "N@multiline_nodegroup",
         "one_list_group": "N@one_minion_list",
         "list_group2": "N@list_nodegroup",
@@ -176,7 +177,7 @@ def salt_master_factory(
         "etcd.port": sdb_etcd_port,
     }
     config_defaults["vault"] = {
-        "url": "http://127.0.0.1:{}".format(vault_port),
+        "url": f"http://127.0.0.1:{vault_port}",
         "auth": {"method": "token", "token": "testsecret", "uses": 0},
         "policies": ["testpolicy"],
     }
@@ -213,7 +214,7 @@ def salt_master_factory(
     config_overrides["external_auth"] = {
         "pam": {
             salt_auth_account_1_factory.username: ["test.*"],
-            "{}%".format(salt_auth_account_2_factory.group_name): [
+            f"{salt_auth_account_2_factory.group_name}%": [
                 "@wheel",
                 "@runner",
                 "test.*",
@@ -311,7 +312,7 @@ def salt_minion_factory(salt_master_factory, salt_minion_id, sdb_etcd_port, vaul
         "etcd.port": sdb_etcd_port,
     }
     config_defaults["vault"] = {
-        "url": "http://127.0.0.1:{}".format(vault_port),
+        "url": f"http://127.0.0.1:{vault_port}",
         "auth": {"method": "token", "token": "testsecret", "uses": 0},
         "policies": ["testpolicy"],
     }
@@ -511,7 +512,7 @@ def tmp_path_world_rw(request):
     Temporary path which is world read/write for tests that run under a different account
     """
     tempdir_path = pathlib.Path(basetemp=tempfile.gettempdir()).resolve()
-    path = tempdir_path / "world-rw-{}".format(id(request.node))
+    path = tempdir_path / f"world-rw-{id(request.node)}"
     path.mkdir(exist_ok=True)
     path.chmod(0o777)
     try:
@@ -643,6 +644,7 @@ def io_loop():
 
 # <---- Async Test Fixtures ------------------------------------------------------------------------------------------
 
+
 # ----- Helpers ----------------------------------------------------------------------------------------------------->
 @pytest.helpers.proxy.register
 def delta_proxy_minion_ids():
