@@ -6,7 +6,6 @@ import shutil
 import sys
 from sysconfig import get_path
 
-import _pytest._version
 import attr
 import pytest
 
@@ -15,12 +14,10 @@ import salt.utils.files
 from tests.conftest import CODE_DIR
 from tests.support.mock import MagicMock, patch
 
-PYTEST_GE_7 = getattr(_pytest._version, "version_tuple", (-1, -1)) >= (7, 0)
-
-
 log = logging.getLogger(__name__)
 
 pytestmark = [
+    pytest.mark.timeout_unless_on_windows(120),
     pytest.mark.destructive_test,
     pytest.mark.skip_if_not_root,
     pytest.mark.slow_test,
@@ -30,11 +27,8 @@ pytestmark = [
 @pytest.fixture
 def pkgrepo(states, grains):
     if grains["os_family"] != "Debian":
-        exc_kwargs = {}
-        if PYTEST_GE_7:
-            exc_kwargs["_use_item_location"] = True
         raise pytest.skip.Exception(
-            "Test only for debian based platforms", **exc_kwargs
+            "Test only for debian based platforms", _use_item_location=True
         )
     return states.pkgrepo
 
@@ -102,12 +96,9 @@ def system_aptsources_ids(value):
 def system_aptsources(request, grains):
     sys_modules = list(sys.modules)
     copied_paths = []
-    exc_kwargs = {}
-    if PYTEST_GE_7:
-        exc_kwargs["_use_item_location"] = True
     if grains["os_family"] != "Debian":
         raise pytest.skip.Exception(
-            "Test only for debian based platforms", **exc_kwargs
+            "Test only for debian based platforms", _use_item_location=True
         )
     try:
         try:
@@ -117,7 +108,7 @@ def system_aptsources(request, grains):
                 raise pytest.skip.Exception(
                     "This test is meant to run without the system aptsources package, but it's "
                     "available from '{}'.".format(sourceslist.__file__),
-                    **exc_kwargs,
+                    _use_item_location=True,
                 )
             else:
                 # Run the test
@@ -162,7 +153,8 @@ def system_aptsources(request, grains):
                             shutil.copyfile(src, dst)
                 if not copied_paths:
                     raise pytest.skip.Exception(
-                        "aptsources.sourceslist python module not found", **exc_kwargs
+                        "aptsources.sourceslist python module not found",
+                        _use_item_location=True,
                     )
                 # Run the test
                 yield request.param
@@ -622,7 +614,7 @@ def test_repo_absent_existing_repo_trailing_slash_uri(
 
     with subtests.test("Remove repo with trailing slash in URI"):
         # Write contents to file with trailing slash in URI
-        repo_file.write_text(f"{repo_content}\n")
+        repo_file.write_text(f"{repo_content}\n", encoding="utf-8")
         # Perform and validate removal
         ret = pkgrepo.absent(name=repo_content)
         assert ret.result
@@ -638,7 +630,7 @@ def test_repo_absent_existing_repo_trailing_slash_uri(
         # Create a repo file that matches the URI but contains no architecture.
         # This should not be identified as a match for repo_content, and thus
         # the result of a state should be a no-op.
-        repo_file.write_text(f"deb {repo_uri} stable main\n")
+        repo_file.write_text(f"deb {repo_uri} stable main\n", encoding="utf-8")
         # Since this was a no-op, the state should have succeeded, made no
         # changes, and left the repo file in place.
         ret = pkgrepo.absent(name=repo_content)
