@@ -14,6 +14,10 @@ def test_system_config(grains):
     """
     if grains["os_family"] == "RedHat":
         if grains["osfinger"] in (
+            "AlmaLinux-8",
+            "AlmaLinux-9",
+            "Rocky Linux-8",
+            "Rocky Linux-9",
             "CentOS Stream-8",
             "CentOS Linux-8",
             "CentOS Stream-9",
