@@ -32,8 +32,7 @@ def test_salt_versions_report_master(install_salt):
     py_version = subprocess.run(
         [str(python_bin), "--version"],
         check=True,
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        capture_output=True,
     ).stdout
     py_version = py_version.decode().strip().replace(" ", ": ")
     ret.stdout.matcher.fnmatch_lines([f"*{py_version}*"])
@@ -126,7 +125,15 @@ def test_compare_pkg_versions_redhat_rc(version, install_salt):
     package of the same version. For example, v3004~rc1 should be less than
     v3004.
     """
-    if install_salt.distro_id not in ("centos", "redhat", "amzn", "fedora", "photon"):
+    if install_salt.distro_id not in (
+        "almalinux",
+        "rocky",
+        "centos",
+        "redhat",
+        "amzn",
+        "fedora",
+        "photon",
+    ):
         pytest.skip("Only tests rpm packages")
 
     pkg = [x for x in install_salt.pkgs if "rpm" in x]
