@@ -4,6 +4,10 @@ from salt.cloud import Cloud
 from salt.exceptions import SaltCloudSystemExit
 from tests.support.mock import MagicMock, patch
 
+pytestmark = [
+    pytest.mark.timeout_unless_on_windows(120),
+]
+
 
 @pytest.fixture
 def master_config(master_opts):
