@@ -111,7 +111,15 @@ class SaltPkgInstall:
 
     @pkg_mngr.default
     def _default_pkg_mngr(self):
-        if self.distro_id in ("centos", "redhat", "amzn", "fedora", "photon"):
+        if self.distro_id in (
+            "almalinux",
+            "rocky",
+            "centos",
+            "redhat",
+            "amzn",
+            "fedora",
+            "photon",
+        ):
             return "yum"
         elif self.distro_id in ("ubuntu", "debian"):
             ret = self.proc.run("apt-get", "update")
@@ -120,7 +128,15 @@ class SaltPkgInstall:
 
     @rm_pkg.default
     def _default_rm_pkg(self):
-        if self.distro_id in ("centos", "redhat", "amzn", "fedora", "photon"):
+        if self.distro_id in (
+            "almalinux",
+            "rocky",
+            "centos",
+            "redhat",
+            "amzn",
+            "fedora",
+            "photon",
+        ):
             return "remove"
         elif self.distro_id in ("ubuntu", "debian"):
             return "purge"
@@ -128,7 +144,15 @@ class SaltPkgInstall:
     @dbg_pkg.default
     def _default_dbg_pkg(self):
         dbg_pkg = None
-        if self.distro_id in ("centos", "redhat", "amzn", "fedora", "photon"):
+        if self.distro_id in (
+            "almalinux",
+            "rocky",
+            "centos",
+            "redhat",
+            "amzn",
+            "fedora",
+            "photon",
+        ):
             dbg_pkg = "salt-debuginfo"
         elif self.distro_id in ("ubuntu", "debian"):
             dbg_pkg = "salt-dbg"
@@ -144,7 +168,15 @@ class SaltPkgInstall:
             "salt-cloud",
             "salt-minion",
         ]
-        if self.distro_id in ("centos", "redhat", "amzn", "fedora", "photon"):
+        if self.distro_id in (
+            "almalinux",
+            "rocky",
+            "centos",
+            "redhat",
+            "amzn",
+            "fedora",
+            "photon",
+        ):
             salt_pkgs.append("salt")
         elif self.distro_id in ("ubuntu", "debian"):
             salt_pkgs.append("salt-common")
@@ -171,7 +203,7 @@ class SaltPkgInstall:
         Default location for salt configurations
         """
         if platform.is_windows():
-            config_path = pathlib.Path("C://salt", "etc", "salt")
+            config_path = pathlib.Path("C:\\salt", "etc", "salt")
         else:
             config_path = pathlib.Path("/etc", "salt")
         return config_path
@@ -209,7 +241,7 @@ class SaltPkgInstall:
                 break
         if not version:
             pytest.fail(
-                f"Failed to package artifacts in '{ARTIFACTS_DIR}'. "
+                f"Failed to find package artifacts in '{ARTIFACTS_DIR}'. "
                 f"Directory Contents:\n{pprint.pformat(artifacts)}"
             )
         return version
@@ -256,7 +288,7 @@ class SaltPkgInstall:
                             self.install_dir / "salt-minion.exe"
                         ).exists() and not self.relenv:
                             log.debug(
-                                f"Removing {(self.install_dir / 'salt-minion.exe')}"
+                                "Removing %s", self.install_dir / "salt-minion.exe"
                             )
                             (self.install_dir / "salt-minion.exe").unlink()
 
@@ -267,6 +299,10 @@ class SaltPkgInstall:
                         self.run_root = self.bin_dir / "run"
                     else:
                         log.error("Unexpected file extension: %s", self.file_ext)
+                log.debug("root: %s", self.root)
+                log.debug("bin_dir: %s", self.bin_dir)
+                log.debug("ssm_bin: %s", self.ssm_bin)
+                log.debug("run_root: %s", self.run_root)
 
         if not self.pkgs:
             pytest.fail("Could not find Salt Artifacts")
@@ -372,21 +408,24 @@ class SaltPkgInstall:
                         self.binary_paths["spm"] = [shutil.which("salt-spm")]
                     else:
                         self.binary_paths["pip"] = [shutil.which("salt-pip")]
+        log.debug("python_bin: %s", python_bin)
+        log.debug("binary_paths: %s", self.binary_paths)
+        log.debug("install_dir: %s", self.install_dir)
 
     @staticmethod
     def salt_factories_root_dir(system_service: bool = False) -> pathlib.Path:
         if system_service is False:
             return None
         if platform.is_windows():
-            return pathlib.Path("C:/salt")
+            return pathlib.Path("C:\\salt")
         if platform.is_darwin():
             return pathlib.Path("/opt/salt")
         return pathlib.Path("/")
 
     def _check_retcode(self, ret):
         """
-        helper function ot check subprocess.run
-        returncode equals 0, if not raise assertionerror
+        Helper function to check subprocess.run returncode equals 0
+        If not raise AssertionError
         """
         if ret.returncode != 0:
             log.error(ret)
@@ -428,8 +467,14 @@ class SaltPkgInstall:
             # Remove the service installed by the installer
             log.debug("Removing installed salt-minion service")
             self.proc.run(str(self.ssm_bin), "remove", "salt-minion", "confirm")
+
+            # Add installation to the path
             self.update_process_path()
 
+            # Install the service using our config
+            if self.pkg_system_service:
+                self._install_ssm_service()
+
         elif platform.is_darwin():
             daemons_dir = pathlib.Path("/Library", "LaunchDaemons")
             service_name = "com.saltstack.salt.minion"
@@ -476,6 +521,54 @@ class SaltPkgInstall:
         log.info(ret)
         self._check_retcode(ret)
 
+    def _install_ssm_service(self, service="minion"):
+        """
+        This function installs the service on Windows using SSM but does not
+        start it.
+
+        Args:
+
+            service (str):
+                The name of the service. Default is ``minion``
+        """
+        service_name = f"salt-{service}"
+        binary = self.install_dir / f"{service_name}.exe"
+        ret = self.proc.run(
+            str(self.ssm_bin),
+            "install",
+            service_name,
+            binary,
+            "-c",
+            f'"{str(self.conf_dir)}"',
+        )
+        self._check_retcode(ret)
+        ret = self.proc.run(
+            str(self.ssm_bin),
+            "set",
+            service_name,
+            "Description",
+            "Salt Minion for testing",
+        )
+        self._check_retcode(ret)
+        # This doesn't start the service. It will start automatically on reboot
+        # It is set here to make it the same as what the installer does
+        ret = self.proc.run(
+            str(self.ssm_bin), "set", service_name, "Start", "SERVICE_AUTO_START"
+        )
+        self._check_retcode(ret)
+        ret = self.proc.run(
+            str(self.ssm_bin), "set", service_name, "AppStopMethodConsole", "24000"
+        )
+        self._check_retcode(ret)
+        ret = self.proc.run(
+            str(self.ssm_bin), "set", service_name, "AppStopMethodWindow", "2000"
+        )
+        self._check_retcode(ret)
+        ret = self.proc.run(
+            str(self.ssm_bin), "set", service_name, "AppRestartDelay", "60000"
+        )
+        self._check_retcode(ret)
+
     def package_python_version(self):
         return self.proc.run(
             str(self.binary_paths["python"][0]),
@@ -518,13 +611,15 @@ class SaltPkgInstall:
             "3006.0"
         )
         distro_name = self.distro_name
-        if distro_name == "centos" or distro_name == "fedora":
+        if distro_name in ("almalinux", "rocky", "centos", "fedora"):
             distro_name = "redhat"
         root_url = "salt/py3/"
         if self.classic:
             root_url = "py3/"
 
         if self.distro_name in [
+            "almalinux",
+            "rocky",
             "redhat",
             "centos",
             "amazon",
@@ -640,7 +735,8 @@ class SaltPkgInstall:
                 Pin: origin "repo.saltproject.io"
                 Pin-Priority: 1001
                 """
-                    )
+                    ),
+                    encoding="utf-8",
                 )
                 cmd.append("--allow-downgrades")
             env = os.environ.copy()
@@ -720,7 +816,7 @@ class SaltPkgInstall:
             self._check_retcode(ret)
 
             if self.pkg_system_service:
-                self._install_system_service()
+                self._install_ssm_service()
 
         elif platform.is_darwin():
             if self.classic:
@@ -1187,8 +1283,8 @@ class PkgSsmSaltDaemonImpl(PkgSystemdSaltDaemonImpl):
 
         # Dereference the internal _process attribute
         self._process = None
-        # Lets log and kill any child processes left behind, including the main subprocess
-        # if it failed to properly stop
+        # Let's log and kill any child processes left behind, including the main
+        # subprocess if it failed to properly stop
         terminate_process(
             pid=pid,
             kill_children=True,
@@ -1487,7 +1583,7 @@ class ApiRequest:
 @pytest.helpers.register
 def download_file(url, dest, auth=None):
     # NOTE the stream=True parameter below
-    with requests.get(url, stream=True, auth=auth) as r:
+    with requests.get(url, stream=True, auth=auth, timeout=60) as r:
         r.raise_for_status()
         with salt.utils.files.fopen(dest, "wb") as f:
             for chunk in r.iter_content(chunk_size=8192):
