@@ -4,9 +4,11 @@
 
     PyTest helpers functions
 """
+
 import logging
 import os
 import pathlib
+import pprint
 import shutil
 import subprocess
 import tempfile
@@ -17,6 +19,7 @@ import warnings
 from contextlib import contextmanager
 
 import attr
+import psutil
 import pytest
 from saltfactories.utils import random_string
 from saltfactories.utils.tempfiles import temp_file
@@ -62,7 +65,7 @@ def temp_state_file(name, contents, saltenv="base", strip_first_newline=True):
         saltenv(str):
             The salt env to use. Either ``base`` or ``prod``
         strip_first_newline(bool):
-            Wether to strip the initial first new line char or not.
+            Whether to strip the initial first new line char or not.
     """
 
     if saltenv == "base":
@@ -70,9 +73,7 @@ def temp_state_file(name, contents, saltenv="base", strip_first_newline=True):
     elif saltenv == "prod":
         directory = RUNTIME_VARS.TMP_PRODENV_STATE_TREE
     else:
-        raise RuntimeError(
-            '"saltenv" can only be "base" or "prod", not "{}"'.format(saltenv)
-        )
+        raise RuntimeError(f'"saltenv" can only be "base" or "prod", not "{saltenv}"')
     return temp_file(
         name, contents, directory=directory, strip_first_newline=strip_first_newline
     )
@@ -110,7 +111,7 @@ def temp_pillar_file(name, contents, saltenv="base", strip_first_newline=True):
         saltenv(str):
             The salt env to use. Either ``base`` or ``prod``
         strip_first_newline(bool):
-            Wether to strip the initial first new line char or not.
+            Whether to strip the initial first new line char or not.
     """
 
     if saltenv == "base":
@@ -118,9 +119,7 @@ def temp_pillar_file(name, contents, saltenv="base", strip_first_newline=True):
     elif saltenv == "prod":
         directory = RUNTIME_VARS.TMP_PRODENV_PILLAR_TREE
     else:
-        raise RuntimeError(
-            '"saltenv" can only be "base" or "prod", not "{}"'.format(saltenv)
-        )
+        raise RuntimeError(f'"saltenv" can only be "base" or "prod", not "{saltenv}"')
     return temp_file(
         name, contents, directory=directory, strip_first_newline=strip_first_newline
     )
@@ -161,7 +160,7 @@ def salt_loader_module_functions(module):
             # Not a function? carry on
             continue
         funcname = func_alias.get(func.__name__) or func.__name__
-        funcs["{}.{}".format(virtualname, funcname)] = func
+        funcs[f"{virtualname}.{funcname}"] = func
     return funcs
 
 
@@ -203,7 +202,7 @@ def remove_stale_master_key(master):
 def remove_stale_proxy_minion_cache_file(proxy_minion, minion_id=None):
     cachefile = os.path.join(
         proxy_minion.config["cachedir"],
-        "dummy-proxy-{}.cache".format(minion_id or proxy_minion.id),
+        f"dummy-proxy-{minion_id or proxy_minion.id}.cache",
     )
     if os.path.exists(cachefile):
         os.unlink(cachefile)
@@ -239,7 +238,7 @@ class TestGroup:
             self._delete_group = True
             log.debug("Created system group: %s", self)
         else:
-            log.debug("Reusing exising system group: %s", self)
+            log.debug("Reusing existing system group: %s", self)
         if self.members:
             ret = self.sminion.functions.group.members(
                 self.name, members_list=self.members
@@ -298,7 +297,7 @@ class TestAccount:
     @group_name.default
     def _default_group_name(self):
         if self.create_group:
-            return "group-{}".format(self.username)
+            return f"group-{self.username}"
         return None
 
     @_group.default
@@ -328,14 +327,14 @@ class TestAccount:
         if not self.sminion.functions.user.info(self.username):
             log.debug("Creating system account: %s", self)
             ret = self.sminion.functions.user.add(self.username)
-            assert ret
+            assert ret is True
             self._delete_account = True
         if salt.utils.platform.is_darwin() or salt.utils.platform.is_windows():
             password = self.password
         else:
             password = self.hashed_password
         ret = self.sminion.functions.shadow.set_password(self.username, password)
-        assert ret
+        assert ret is True
         assert self.username in self.sminion.functions.user.list_users()
         if self._group:
             self.group.__enter__()
@@ -347,7 +346,7 @@ class TestAccount:
         if self._delete_account:
             log.debug("Created system account: %s", self)
         else:
-            log.debug("Reusing exisintg system account: %s", self)
+            log.debug("Reusing existing system account: %s", self)
         # Run tests
         return self
 
@@ -703,16 +702,20 @@ class EntropyGenerator:
         kernel_entropy_file = pathlib.Path("/proc/sys/kernel/random/entropy_avail")
         kernel_poolsize_file = pathlib.Path("/proc/sys/kernel/random/poolsize")
         if not kernel_entropy_file.exists():
-            log.info("The '%s' file is not avilable", kernel_entropy_file)
+            log.info("The '%s' file is not available", kernel_entropy_file)
             return
 
-        self.current_entropy = int(kernel_entropy_file.read_text().strip())
+        self.current_entropy = int(
+            kernel_entropy_file.read_text(encoding="utf-8").strip()
+        )
         log.info("Available Entropy: %s", self.current_entropy)
 
         if not kernel_poolsize_file.exists():
-            log.info("The '%s' file is not avilable", kernel_poolsize_file)
+            log.info("The '%s' file is not available", kernel_poolsize_file)
         else:
-            self.current_poolsize = int(kernel_poolsize_file.read_text().strip())
+            self.current_poolsize = int(
+                kernel_poolsize_file.read_text(encoding="utf-8").strip()
+            )
             log.info("Entropy Poolsize: %s", self.current_poolsize)
             # Account for smaller poolsizes using BLAKE2s
             if self.current_poolsize == 256:
@@ -738,7 +741,9 @@ class EntropyGenerator:
                         raise pytest.skip.Exception(message, _use_item_location=True)
                     raise pytest.fail(message)
                 subprocess.run([rngd, "-r", "/dev/urandom"], shell=False, check=True)
-                self.current_entropy = int(kernel_entropy_file.read_text().strip())
+                self.current_entropy = int(
+                    kernel_entropy_file.read_text(encoding="utf-8").strip()
+                )
                 log.info("Available Entropy: %s", self.current_entropy)
                 if self.current_entropy >= self.minimum_entropy:
                     break
@@ -773,7 +778,9 @@ class EntropyGenerator:
                     check=True,
                 )
                 os.unlink(target_file.name)
-                self.current_entropy = int(kernel_entropy_file.read_text().strip())
+                self.current_entropy = int(
+                    kernel_entropy_file.read_text(encoding="utf-8").strip()
+                )
                 log.info("Available Entropy: %s", self.current_entropy)
                 if self.current_entropy >= self.minimum_entropy:
                     break
@@ -813,6 +820,61 @@ def change_cwd(path):
         os.chdir(old_cwd)
 
 
+@contextmanager
+def reap_stray_processes(pid: int = os.getpid()):
+
+    try:
+        pre_children = psutil.Process(pid).children(recursive=True)
+        # Do stuff
+        yield
+    finally:
+        post_children = psutil.Process(pid).children(recursive=True)
+
+    children = []
+    for process in post_children:
+        if process in pre_children:
+            # Process existed before entering the context
+            continue
+        if not psutil.pid_exists(process.pid):
+            # Process just died
+            continue
+        # This process is alive and was not running before entering the context
+        children.append(process)
+
+    if not children:
+        log.info("No astray processes found")
+        return
+
+    def on_terminate(proc):
+        log.debug("Process %s terminated with exit code %s", proc, proc.returncode)
+
+    if children:
+        # Reverse the order, sublings first, parents after
+        children.reverse()
+        log.warning(
+            "Test suite left %d astray processes running. Killing those processes:\n%s",
+            len(children),
+            pprint.pformat(children),
+        )
+
+        _, alive = psutil.wait_procs(children, timeout=3, callback=on_terminate)
+        for child in alive:
+            try:
+                child.kill()
+            except psutil.NoSuchProcess:
+                continue
+
+        _, alive = psutil.wait_procs(alive, timeout=3, callback=on_terminate)
+        if alive:
+            # Give up
+            for child in alive:
+                log.warning(
+                    "Process %s survived SIGKILL, giving up:\n%s",
+                    child,
+                    pprint.pformat(child.as_dict()),
+                )
+
+
 # Only allow star importing the functions defined in this module
 __all__ = [
     name
